# Try to find cDIRT library installation.
# This script has been written by Ludovic Magerand.
#
# The following variable are checked as possible root directory :
#  cDIRT_ROOT_DIR
#  ENV{cDIRT_ROOT_DIR}
#
# The following are set after configuration is done :
#  cDIRT_FOUND
#  cDIRT_INCLUDE_DIR
#  cDIRT_LIBRARY
#  cDIRT_LINK_DIR
#
# tested with OpenCV 1.0.0 and generators :
#  Unix Makefiles
#  Code::Blocks - Unix Makefiles
#  Code::Blocks - MinGW Makefiles

# typical root dirs of installations, exactly one of them is used
set( cDIRT_POSSIBLE_ROOT_DIRS
		"${cDIRT_ROOT_DIR}"
		"$ENV{cDIRT_ROOT_DIR}"  
		"$ENV{ProgramFiles}/cDIRT"
		/usr/local
		/usr )

# select exactly ONE of this base directory
find_path( cDIRT_ROOT_DIR NAMES include/cdirt.h
		PATHS ${cDIRT_POSSIBLE_ROOT_DIRS} )

# set the include directory
set( cDIRT_INCLUDE_DIR ${cDIRT_ROOT_DIR}/include )

# find the library
find_library( cDIRT_LIBRARY NAMES cdirt
		PATHS ${cDIRT_ROOT_DIR} PATH_SUFFIXES lib )

# get the link directory for rpath to be used with LINK_DIRECTORIES: 
if( cDIRT_LIBRARY )
	get_filename_component( cDIRT_LINK_DIR ${cDIRT_LIBRARY} PATH )
endif( cDIRT_LIBRARY )

if( cDIRT_ROOT_DIR AND cDIRT_LIBRARY )
	set( cDIRT_FOUND ON )
endif( cDIRT_ROOT_DIR AND cDIRT_LIBRARY )

# mark internal variable as advanced
mark_as_advanced( cDIRT_ROOT_DIR cDIRT_INCLUDE_DIR cDIRT_LIBRARY cDIRT_LINK_DIR cDIRT_FOUND )

# display help message
if( NOT cDIRT_FOUND )
	# make FIND_PACKAGE friendly
	if( NOT cDIRT_FIND_QUIETLY )
		if( cDIRT_FIND_REQUIRED )
			message( FATAL_ERROR "cDIRT required but header or lib not found. Specify its location with OpenCV_ROOT_DIR variable." )
		else( cDIRT_FIND_REQUIRED )
			message( STATUS "cDIRT was not found." )
		endif( cDIRT_FIND_REQUIRED )
	endif( NOT cDIRT_FIND_QUIETLY )
endif( NOT cDIRT_FOUND )
