/*
 * This file goes with the cDIRT C++ image registration package.
 * 
 * It implements some of the methods described in the following paper :
 * Groupwise Geometric and Photometric Direct Image Registration
 * A. Bartoli in IEEE Transactions on Pattern Analysis and Machine Intelligence,
 * Vol. 30, No. 12, pp. 2098-2108, December 2008.
 * Should you use cDIRT, please cite the above paper.
 *
 * cDIRT has been implemented by Pierre Georgel and packaged by Ludovic Magerand.
 * It is based on the (more comprehensive) Matlab implementation by Adrien Bartoli.
 *
 */

#include "cdirt.h"

#include <iostream>
#include <cxcore.h>
#include <highgui.h>

int main(int argc, char* argv[])
{
	IplImage *src = cvLoadImage("source.jpg");
	IplImage *tgt = cvLoadImage("target.jpg");	
	
	
	if ((!tgt)||(!src)) {
		std::cout << "Could not open src or tgt image!" <<std::endl;
		exit(-1);
	}

	CDIRT_struct data_src;
	data_src.options[0] = CDIRT_PNORM;
	
	
 	CDIRT_Precomputation(src, &data_src,
		cvRect(50,50,src->width-100,src->height-100));

	CDIRT_Registration(tgt, &data_src);

	CDIRT_releaseData(&data_src);
	cvReleaseImage(&src);
	cvReleaseImage(&tgt);

	return 0;
}
