/*
 * This file goes with the cDIRT C++ image registration package.
 * 
 * It implements some of the methods described in the following paper :
 * Groupwise Geometric and Photometric Direct Image Registration
 * A. Bartoli in IEEE Transactions on Pattern Analysis and Machine Intelligence,
 * Vol. 30, No. 12, pp. 2098-2108, December 2008.
 * Should you use cDIRT, please cite the above paper.
 *
 * cDIRT has been implemented by Pierre Georgel and packaged by Ludovic Magerand.
 * It is based on the (more comprehensive) Matlab implementation by Adrien Bartoli.
 *
 */

#ifndef CDIRT_H
#define CDIRT_H
#include <cv.h>
#include <cxcore.h>
#include <highgui.h>

#include <fstream>
#include <string>

#define CDIRT_POPTIM 1
#define CDIRT_NO_POPTIM 0

// Toggle normalization of the pixel values on
#define CDIRT_PNORM 1
#define CDIRT_NO_PNORM 0// Toggle normalization of the pixel values off

#define CDIRT_QUIET 0
#define CDIRT_VERBOSE 1

#define CDIRT_MIN_STEP_SIZE 1e-5
#define CDIRT_MAX_NB_IT 100
//exp(- (x.^2) / (2*sigma^2));
#define GAUSSIAN(x,sig) exp(-x*x/(2.0f * sig*sig))

typedef struct{
	CvMat *sI_ROI; //The source image pixels 
	CvMat *SD_ROI; //The steepest descent images for the region of interest
    CvMat *warp; //matrix used to store the warp
    CvMat *tI;
	CvMat *tIT;

	CvMat *invH; //The inverse of the Hessian matrix for the normal equations
	CvMat *H; //The Hessian matrix for the normal equations

	CvMat *G; //The homography resulting from the registration process.
	CvMat *P; //The gain and bais resulting from the registration process.

	CvMat *b;
	CvMat *dp;
	CvMat *dH;
	CvMat *	invdH;

	float initErr;
	float finalErr;
	
	bool converged;

	int nChannels;
	int w;
	int h;
	float pnorm;

	CvRect ROI;

	int options[3];
} CDIRT_struct;

int writeCvMatToMfile(const CvMat* src, const char *variableName);
int saveCdirtStructure(const std::string & filename, CDIRT_struct * data);
bool badWarp(const CvMat *H, int w, int h, CvRect ROI);
int warpImage(const IplImage *src, IplImage *dst, CvMat *H, CvRect ROI);

void CDIRT_releaseData(CDIRT_struct* data);
void CDIRT_Precomputation(const IplImage* src, CDIRT_struct* data, CvRect ROI);
void CDIRT_Registration(const IplImage *tgt,CDIRT_struct* data);
void CDIRT_getTargetROI(CDIRT_struct *data, CvMat* tgtPoints);


#endif // CDIRT_H

